
package de.test.framework;


import java.io.Serializable;


/**
 * Value Object zur Kapselung einer Exception
 */
public class ServerExceptionSO implements Serializable
{
   private static final long serialVersionUID   = 4813865951995456215L;

   private String            m_ExceptionType    = "";

   private String            m_Origin           = "";
   private String            m_Category         = "";

   private String            m_Level            = "";
   private String            m_Cause            = "";
   private String            m_LogInfo          = "";

   private String            m_User             = "";
   private String            m_Host             = "";
   private String            m_Application      = "";

   private String            m_ErrorDescription = "";
   private String            m_Stacktrace       = "";
   private String            m_ErrorCode        = "";
   private String            m_RawErrorDescr    = "";

   // Bedeutung der Fehlermeldung steht in ErrorDescription


   /**
    * Konstruktor
    * 
    * @param p_ExceptionType Type der gemappten Exception (Bsp. DAOException)
    * @param p_Origin Ursprung
    * @param p_Category Kategorie
    * @param p_Level Level
    * @param p_Cause Ursache
    * @param p_LogInfo LogId
    * @param p_User Benutzername
    * @param p_Host Hostname
    * @param p_Application Anwendungsname
    * @param p_ErrorDescription Fehlerbeschreibung
    * @param p_Stacktrace Stacktrace
    * @param p_ErrorCode Fehlercode
    * @param p_RawErrorDescr Nicht bersetzte Fehlerbeschreibung
    */
   public ServerExceptionSO( String p_ExceptionType,
                             String p_Origin,
                             String p_Category,
                             String p_Level,
                             String p_Cause,
                             String p_LogInfo,
                             String p_User,
                             String p_Host,
                             String p_Application,
                             String p_ErrorDescription,
                             String p_Stacktrace,
                             String p_ErrorCode,
                             String p_RawErrorDescr)
   {
      m_ExceptionType = p_ExceptionType;
      m_Origin = p_Origin;
      m_Category = p_Category;
      m_Level = p_Level;
      m_Cause = p_Cause;
      m_LogInfo = p_LogInfo;
      m_User = p_User;
      m_Host = p_Host;
      m_Application = p_Application;
      m_ErrorDescription = p_ErrorDescription;
      m_Stacktrace = p_Stacktrace;
      m_ErrorCode = p_ErrorCode;
      m_RawErrorDescr = p_RawErrorDescr;
   }
   
   /**
    * Getter fr exceptionType.
    * @return Liefert exceptionType.
    */
   public String getExceptionType()
   {
      return m_ExceptionType;
   }

   /**
    * Setter fr exceptionType.
    * @param p_ExceptionType Wert fr exceptionType.
    */
   public void setExceptionType( String p_ExceptionType )
   {
      m_ExceptionType = p_ExceptionType;
   }

   /**
    * Getter-Methode
    * 
    * @return Liefert Kategorie.
    */
   public String getCategory()
   {
      return m_Category;
   }

   /**
    * Setter-Methode
    * 
    * @param p_Category Wert fr Kategorie.
    */
   public void setCategory( String p_Category )
   {
      m_Category = p_Category;
   }

   /**
    * Getter-Methode
    * 
    * @return Liefert Ursache.
    */
   public String getCause()
   {
      return m_Cause;
   }

   /**
    * Setter-Methode
    * 
    * @param p_Cause Wert fr Ursache.
    */
   public void setCause( String p_Cause )
   {
      m_Cause = p_Cause;
   }

   /**
    * Getter-Methode
    * 
    * @return Liefert Ursprung.
    */
   public String getOrigin()
   {
      return m_Origin;
   }

   /**
    * Setter-Methode
    * 
    * @param p_Origin Wert fr Ursprung.
    */
   public void setOrigin( String p_Origin )
   {
      m_Origin = p_Origin;
   }

   /**
    * Getter-Methode
    * 
    * @return Liefert Fehlerbeschreibung.
    */
   public String getErrorDescription()
   {
      return m_ErrorDescription;
   }

   /**
    * Setter-Methode
    * 
    * @param p_ErrorDescription Wert fr Fehlerbeschreibung.
    */
   public void setErrorDescription( String p_ErrorDescription )
   {
      m_ErrorDescription = p_ErrorDescription;
   }

   /**
    * Getter-Methode
    * 
    * @return Liefert Level.
    */
   public String getLevel()
   {
      return m_Level;
   }

   /**
    * Setter-Methode
    * 
    * @param p_Level Wert fr Level.
    */
   public void setLevel( String p_Level )
   {
      m_Level = p_Level;
   }

   /**
    * Getter-Methode
    * 
    * @return Liefert LogInfo.
    */
   public String getLogInfo()
   {
      return m_LogInfo;
   }

   /**
    * Setter-Methode
    * 
    * @param p_LogInfo Wert.
    */
   public void setLogInfo( String p_LogInfo )
   {
      m_LogInfo = p_LogInfo;
   }

   /**
    * Liefert den Benutzernamen
    * 
    * @return Benutzername
    */
   public String getUser()
   {
      return m_User;
   }

   /**
    * Setzt den Benutzernamen
    * 
    * @param p_User Benutzername
    */
   public void setUser( String p_User )
   {
      m_User = p_User;
   }

   /**
    * Liefert den Hostnamen
    * 
    * @return Hostname
    */
   public String getHost()
   {
      return m_Host;
   }

   /**
    * Setzt den Hostnamen
    * 
    * @param p_Host Hostname
    */
   public void setHost( String p_Host )
   {
      m_Host = p_Host;
   }

   /**
    * Liefert den Anwendungsnamen
    * 
    * @return Anwendungsname
    */
   public String getApplication()
   {
      return m_Application;
   }

   /**
    * Setzt den Anwendungsnamen
    * 
    * @param p_Application Anwendungsname
    */
   public void setApplication( String p_Application )
   {
      m_Application = p_Application;
   }

   /**
    * Getter-Methode
    * 
    * @return Liefert den Stacktrace.
    */
   public String getStacktrace()
   {
      return m_Stacktrace;
   }

   /**
    * Setter-Methode
    * @param p_Stacktrace Wert fr Stacktrace.
    */
   public void setStacktrace( String p_Stacktrace )
   {
      m_Stacktrace = p_Stacktrace;
   }

   /**
    * Getter-Methode
    * @return Liefert errorCode.
    */
   public String getErrorCode()
   {
      return m_ErrorCode;
   }

   /**
    * Setter-Methode
    * @param p_ErrorCode Wert fr errorCode.
    */
   public void setErrorCode( String p_ErrorCode )
   {
      m_ErrorCode = p_ErrorCode;
   }

   /**
    * Getter fr rawErrorDescr.
    * @return Liefert rawErrorDescr.
    */
   public String getRawErrorDescr()
   {
      return m_RawErrorDescr;
   }

   /**
    * Setter fr rawErrorDescr.
    * @param p_RawErrorDescr Wert fr rawErrorDescr.
    */
   public void setRawErrorDescr( String p_RawErrorDescr )
   {
      m_RawErrorDescr = p_RawErrorDescr;
   }
}
